@@ -1,32 +1,32 @@
-( cd usr/lib64 ; rm -rf libbfb.so.0 )
-( cd usr/lib64 ; ln -sf libbfb.so.0.0.4 libbfb.so.0 )
-( cd usr/lib64 ; rm -rf libbfb.so )
-( cd usr/lib64 ; ln -sf libbfb.so.0.0.4 libbfb.so )
-( cd usr/lib64 ; rm -rf libmulticobex.so.1 )
-( cd usr/lib64 ; ln -sf libmulticobex.so.1.0.0 libmulticobex.so.1 )
-( cd usr/lib64 ; rm -rf libmulticobex.so )
-( cd usr/lib64 ; ln -sf libmulticobex.so.1.0.0 libmulticobex.so )
-( cd usr/lib64 ; rm -rf libobexftp.so.0 )
-( cd usr/lib64 ; ln -sf libobexftp.so.0.1.0 libobexftp.so.0 )
-( cd usr/lib64 ; rm -rf libobexftp.so )
-( cd usr/lib64 ; ln -sf libobexftp.so.0.1.0 libobexftp.so )
-( cd usr/lib64/python2.5/site-packages/obexftp ; rm -rf _obexftp.so.0 )
-( cd usr/lib64/python2.5/site-packages/obexftp ; ln -sf _obexftp.so.0.0.0 _obexftp.so.0 )
-( cd usr/lib64/python2.5/site-packages/obexftp ; rm -rf _obexftp.so )
-( cd usr/lib64/python2.5/site-packages/obexftp ; ln -sf _obexftp.so.0.0.0 _obexftp.so )
 ( cd usr/bin ; rm -rf obexls )
 ( cd usr/bin ; ln -sf obexftp obexls )
+( cd usr/bin ; rm -rf obexrm )
+( cd usr/bin ; ln -sf obexftp obexrm )
 ( cd usr/bin ; rm -rf obexget )
 ( cd usr/bin ; ln -sf obexftp obexget )
 ( cd usr/bin ; rm -rf obexput )
 ( cd usr/bin ; ln -sf obexftp obexput )
-( cd usr/bin ; rm -rf obexrm )
-( cd usr/bin ; ln -sf obexftp obexrm )
+( cd usr/man/man1 ; rm -rf obexrm.1.gz )
+( cd usr/man/man1 ; ln -sf obexftp.1.gz obexrm.1.gz )
+( cd usr/man/man1 ; rm -rf obexput.1.gz )
+( cd usr/man/man1 ; ln -sf obexftp.1.gz obexput.1.gz )
 ( cd usr/man/man1 ; rm -rf obexls.1.gz )
 ( cd usr/man/man1 ; ln -sf obexftp.1.gz obexls.1.gz )
 ( cd usr/man/man1 ; rm -rf obexget.1.gz )
 ( cd usr/man/man1 ; ln -sf obexftp.1.gz obexget.1.gz )
-( cd usr/man/man1 ; rm -rf obexput.1.gz )
-( cd usr/man/man1 ; ln -sf obexftp.1.gz obexput.1.gz )
-( cd usr/man/man1 ; rm -rf obexrm.1.gz )
-( cd usr/man/man1 ; ln -sf obexftp.1.gz obexrm.1.gz )
+( cd usr/lib64 ; rm -rf libbfb.so.0 )
+( cd usr/lib64 ; ln -sf libbfb.so.0.0.5 libbfb.so.0 )
+( cd usr/lib64 ; rm -rf obexftp.so.0 )
+( cd usr/lib64 ; ln -sf obexftp.so.0.0.0 obexftp.so.0 )
+( cd usr/lib64 ; rm -rf libmulticobex.so.1 )
+( cd usr/lib64 ; ln -sf libmulticobex.so.1.0.1 libmulticobex.so.1 )
+( cd usr/lib64 ; rm -rf libmulticobex.so )
+( cd usr/lib64 ; ln -sf libmulticobex.so.1.0.1 libmulticobex.so )
+( cd usr/lib64 ; rm -rf obexftp.so )
+( cd usr/lib64 ; ln -sf obexftp.so.0.0.0 obexftp.so )
+( cd usr/lib64 ; rm -rf libobexftp.so.0 )
+( cd usr/lib64 ; ln -sf libobexftp.so.0.2.0 libobexftp.so.0 )
+( cd usr/lib64 ; rm -rf libobexftp.so )
+( cd usr/lib64 ; ln -sf libobexftp.so.0.2.0 libobexftp.so )
+( cd usr/lib64 ; rm -rf libbfb.so )
+( cd usr/lib64 ; ln -sf libbfb.so.0.0.5 libbfb.so )
